@@ -974,6 +974,15 @@ handle_spec_block.specODE <- function(x, env, ...) {
   return(x)
 }
 
+# MAIN -------------------------------------------------------------------------
+
+#' @export
+handle_spec_block.specMAIN <- function(x,env,...) {
+  x <- scrape_opts(x, def = list(check_modeled_infusions = TRUE))
+  env$check_modeled_infusions <- isTRUE(x$check_modeled_infusions)
+  return(x$x)  
+}
+
 # BLOCK ------------------------------------------------------------------------
 
 #' @export
