@@ -17,15 +17,6 @@
 
 setAs("NULL", "character", function(from) character(0))
 
-sval <- unique(c("atol","rtol","ss_rtol", "ss_atol",
-                 "verbose","debug","preclean","mindt",
-                 "digits", "ixpr", "mxhnil","start", "end", "add", "delta",
-                 "maxsteps", "hmin", "hmax","tscale", "request"))
-
-other_val <- c("param", "init", "omega", "sigma", "outvars")
-
-all_updatable <- c(sval,other_val)
-
 #' Update the model object
 #'
 #' After the model object is created, update various attributes.
@@ -94,7 +85,7 @@ setMethod("update", "mrgmod", function(object, ..., merge=TRUE, open=FALSE,
   # TODO: get rid of the merge argument to `update()`
   # TODO: get rid of the open argument to `update()`
   # TODO: longer term ... error when bad arguments are passed
-
+  
   args <- list(...)
   
   if(!is.null(data)) {
@@ -107,7 +98,7 @@ setMethod("update", "mrgmod", function(object, ..., merge=TRUE, open=FALSE,
   
   a <- names(args)
   
-  m <- charmatch(a, all_updatable)
+  m <- charmatch(a, GLOBALS$UPDATE_ALL)
   
   if(anyNA(m) && isTRUE(strict)) {
     if(!is.null(getOption("mrgsolve.update.strict"))) {
@@ -131,10 +122,10 @@ setMethod("update", "mrgmod", function(object, ..., merge=TRUE, open=FALSE,
     warn(msg, call = NULL)
   }
   
-  valid <- !is.na(m)
-  a[valid] <- all_updatable[m[valid]]
+  valid <- !is.na(m) & m != 0
+  a[valid] <- GLOBALS$UPDATE_ALL[m[valid]]
   names(args) <- a
-  valid.in <- which(a %in% sval)
+  valid.in <- which(a %in% GLOBALS$UPDATE_SINGLE)
   if(length(valid.in) > 0) {
     for(i in seq_along(valid.in)) {
       slot(object, a[valid.in[i]]) <- args[[a[valid.in[i]]]]
